@@ -11,7 +11,7 @@ def parse_raw_df(df_hour_raw):
         df_hour_raw.columns = columns_names
         selected_idxes = []
         for idx in df_hour_raw.index:
-            if "Ringer Mode" in df_hour_raw['LOG'][idx]:
+            if "Ringer Mode" in str(df_hour_raw['LOG'][idx]):
                 selected_idxes.append(idx)
 
         df_hour_raw = df_hour_raw.iloc[selected_idxes]
